-- *************************************
-- Use Replace to change the following two items
-- (1) Replace <DB> with the name of the database to create
--	usually: change <DB> to PetStore   (remove the brackets)
-- (2) Replace <PATH> with the full path to this file
--	example: change <PATH> to C:\Temp\PetStore\
-- *************************************

IF NOT EXISTS (SELECT * FROM sys.databases
	WHERE name = N'<DB>')
	CREATE DATABASE <DB>
GO
USE <DB>
--
-- Create the path to the CSV files
--
DECLARE @data_path nvarchar(256);
SELECT @data_path = '<PATH>';
--

-- *************************************
-- Drop existing tables
-- *************************************

IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'SaleItem')
   drop table SaleItem;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Sale')
  drop table Sale;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'OrderItem')
  drop table OrderItem;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'MerchandiseOrder')
  drop table MerchandiseOrder;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Merchandise')
  drop table Merchandise;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Supplier')
  drop table Supplier;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Customer')
  drop table Customer;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Employee')
  drop table Employee;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Animal')
  drop table Animal;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'AdoptionGroup')
  drop table AdoptionGroup;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'City')
  drop table City;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Breed')
  drop table Breed;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Category')
  drop table Category;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Revision')
  drop table Revision;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Preferences')
  drop table Preferences;

-- *************************************
-- Create the tables
-- *************************************

CREATE TABLE Preferences
(
KeyID         nvarchar(100),
Value         nvarchar(200) NULL,
Description   nvarchar(200) NULL,
     CONSTRAINT pk_Preferences PRIMARY KEY (KeyID)
)
--
CREATE TABLE Revision
(
RevisionID    int identity(1,1),
Version       nvarchar(100),
Description   nvarchar(1023) NULL,
Author        nvarchar(255) NULL,
ReleaseDate   smalldatetime NULL,
     CONSTRAINT pk_Revision PRIMARY KEY (RevisionID)
)
--
CREATE TABLE Category
(
Category      nvarchar(100),
Registration  nvarchar(100) NULL,
     CONSTRAINT pk_Category PRIMARY KEY (Category)
)
--
CREATE TABLE Breed
(
Category      nvarchar(100),
Breed         nvarchar(100),
     CONSTRAINT pk_Breed PRIMARY KEY (Category,Breed),
     CONSTRAINT fk_CategoryBreed FOREIGN KEY (Category)
        REFERENCES Category(Category)
        ON DELETE CASCADE 
        ON UPDATE CASCADE
)
--
CREATE TABLE City
(
CityID        int identity(1,1),
ZipCode       nvarchar(50) NULL,
City          nvarchar(100) NULL,
State         nvarchar(100) NULL,
AreaCode      nvarchar(50) NULL,
Population1990              int
     DEFAULT 0 NULL,
Population1980              int
     DEFAULT 0 NULL,
Country       nvarchar(50)
     DEFAULT '"USA"' NULL,
Latitude     real
     DEFAULT 0 NULL,
Longitude    real
     DEFAULT 0 NULL,
     CONSTRAINT pk_City PRIMARY KEY (CityID)
)
--
CREATE TABLE AdoptionGroup
(
AdoptionID       int identity (1,1),
AdoptionSource   nvarchar(200),
ContactName      nvarchar(200) NULL,
ContactPhone     nvarchar(100) NULL,
   Constraint pk_AdoptionGroup PRIMARY KEY (AdoptionID)
)
--
CREATE TABLE Animal
(
AnimalID      int identity(1,1),
Name          nvarchar(100) NULL,
Category      nvarchar(100) NULL,
Breed         nvarchar(100) NULL,
DateBorn      smalldatetime NULL,
Gender        nvarchar(50)
     CHECK (Gender='Male' Or Gender='Female' Or Gender='Unknown' Or Gender Is Null) NULL,
Registered    nvarchar(50) NULL,
Color         nvarchar(100) NULL,
Photo         image NULL,
ImageFile     nvarchar(250) NULL,
ImageHeight   int NULL,
ImageWidth    int NULL,
SaleID        int NULL,
AdoptionID    int NULL,
Donation       money
     DEFAULT 0 NULL,
     CONSTRAINT pk_Animal PRIMARY KEY (AnimalID),
     CONSTRAINT fk_BreedAnimal FOREIGN KEY (Category,Breed)
        REFERENCES Breed(Category,Breed)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
     CONSTRAINT fk_Adoption_AdoptionGroup FOREIGN KEY (AdoptionID)
        REFERENCES AdoptionGroup(AdoptionID)
        ON DELETE CASCADE
        ON UPDATE CASCADE
)
--
CREATE TABLE Employee
(
EmployeeID    int identity(1,1),
LastName      nvarchar(100) NULL,
FirstName     nvarchar(100) NULL,
Phone         nvarchar(100) NULL,
Address       nvarchar(100) NULL,
ZipCode       nvarchar(100) NULL,
CityID        int
     DEFAULT 0 NULL,
TaxPayerID    nvarchar(50) NULL,
DateHired     smalldatetime NULL,
DateReleased  smalldatetime NULL,
ManagerID     int
     DEFAULT 0 NULL,
EmployeeLevel int
     DEFAULT 0 NULL,
Title         nvarchar(50) NULL,
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID),
     CONSTRAINT fk_CityEmployee FOREIGN KEY (CityID)
        REFERENCES City(CityID)
)
--
CREATE TABLE Customer
(
CustomerID    int identity(1,1),
Phone         nvarchar(100) NULL,
FirstName     nvarchar(100) NULL,
LastName      nvarchar(100) NULL,
Address       nvarchar(100) NULL,
ZipCode       nvarchar(50) NULL,
CityID        int
     DEFAULT 0 NULL,
     CONSTRAINT pk_Customer PRIMARY KEY (CustomerID),
     CONSTRAINT fk_CityCustomer FOREIGN KEY (CityID)
        REFERENCES City(CityID)
)
--
CREATE TABLE Supplier
(
SupplierID    int identity(1,1),
Name          nvarchar(100) NULL,
ContactName   nvarchar(100) NULL,
Phone         nvarchar(100) NULL,
Address       nvarchar(100) NULL,
ZipCode       nvarchar(50) NULL,
CityID        int
     DEFAULT 0 NULL,
     CONSTRAINT pk_Supplier PRIMARY KEY (SupplierID),
     CONSTRAINT fk_CitySupplier FOREIGN KEY (CityID)
        REFERENCES City(CityID)
)
--
CREATE TABLE Merchandise
(
ItemID        int identity(1,1),
Description   nvarchar(250) NULL,
QuantityOnHand              int
     DEFAULT 0 NULL,
ListPrice     money
     DEFAULT 0 NULL,
Category      nvarchar(100) NULL,
     CONSTRAINT pk_Merchandise PRIMARY KEY (ItemID),
     CONSTRAINT fk_CategoryMerchandise FOREIGN KEY (Category)
        REFERENCES Category(Category)
        ON DELETE CASCADE
        ON UPDATE CASCADE
)
--
CREATE TABLE MerchandiseOrder
(
PONumber      int,
OrderDate     smalldatetime NULL,
ReceiveDate   smalldatetime NULL,
SupplierID    int
     DEFAULT 0 NULL,
EmployeeID    int
     DEFAULT 0 NULL,
ShippingCost  money
     DEFAULT 0 NULL,
     CONSTRAINT pk_MerchandiseOrder PRIMARY KEY (PONumber),
     CONSTRAINT fk_EmployeeOrder FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
     CONSTRAINT fk_SupplierOrder FOREIGN KEY (SupplierID)
        REFERENCES Supplier(SupplierID)
        ON DELETE CASCADE
        ON UPDATE CASCADE
)
--
CREATE TABLE OrderItem
(
PONumber      int
     DEFAULT 0 NOT NULL,
ItemID        int
     DEFAULT 0 NOT NULL,
Quantity     real
     DEFAULT 0 NULL,
Cost          money
     DEFAULT 0 NULL,
     CONSTRAINT pk_OrderItem PRIMARY KEY (PONumber,ItemID),
     CONSTRAINT fk_MerchandiseOrderItem FOREIGN KEY (ItemID)
        REFERENCES Merchandise(ItemID)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
     CONSTRAINT fk_OrderOrderItem FOREIGN KEY (PONumber)
        REFERENCES MerchandiseOrder(PONumber)
        ON DELETE CASCADE
        ON UPDATE CASCADE
)
--
CREATE TABLE Sale
(
SaleID        int identity(1,1),
SaleDate      smalldatetime NULL,
EmployeeID    int
     DEFAULT 0 NULL,
CustomerID    int
     DEFAULT 0 NULL,
SalesTax      money
     DEFAULT 0 NULL,
     CONSTRAINT pk_Sale PRIMARY KEY (SaleID),
     CONSTRAINT fk_CustomerSale FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
     CONSTRAINT fk_EmployeeSale FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE
        ON UPDATE CASCADE
)
--
CREATE TABLE SaleItem
(
SaleID        int
     DEFAULT 0 NOT NULL,
ItemID        int
     DEFAULT 0 NOT NULL,
Quantity      int
     DEFAULT 0 NULL,
SalePrice     money
     DEFAULT 0 NULL,
     CONSTRAINT pk_SaleItem PRIMARY KEY (SaleID,ItemID),
     CONSTRAINT fk_MerchandiseSaleItem FOREIGN KEY (ItemID)
        REFERENCES Merchandise(ItemID)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
     CONSTRAINT fk_SaleSaleItem FOREIGN KEY (SaleID)
        REFERENCES Sale(SaleID)
        ON DELETE CASCADE
        ON UPDATE CASCADE
)
--
-- *************************************
-- Load table data
-- *************************************
--
EXECUTE (N'BULK INSERT Preferences FROM ''' + @data_path + N'Preferences.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Revision FROM ''' + @data_path + N'Revision.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Category FROM ''' + @data_path + N'Category.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Breed FROM ''' + @data_path + N'Breed.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT City FROM ''' + @data_path + N'City.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT AdoptionGroup FROM ''' + @data_path + N'AdoptionGroup.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Animal FROM ''' + @data_path + N'Animal.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Employee FROM ''' + @data_path + N'Employee.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Customer FROM ''' + @data_path + N'Customer.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Supplier FROM ''' + @data_path + N'Supplier.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Merchandise FROM ''' + @data_path + N'Merchandise.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT MerchandiseOrder FROM ''' + @data_path + N'MerchandiseOrder.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT OrderItem FROM ''' + @data_path + N'OrderItem.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Sale FROM ''' + @data_path + N'Sale.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT SaleItem FROM ''' + @data_path + N'SaleItem.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');

-- ********************
-- List table names and row counts
-- ********************
GO
SET NOCOUNT ON
SELECT 'Preferences' "Table", Count(*) "Rows" FROM Preferences UNION
SELECT 'Revision',            Count(*) FROM Revision           UNION
SELECT 'Category',            Count(*) FROM Category           UNION
SELECT 'Breed',               Count(*) FROM Breed              UNION
SELECT 'City',                Count(*) FROM City               UNION
SELECT 'AdoptionGroup',       Count(*) FROM AdoptionGroup      UNION
SELECT 'Animal',              Count(*) FROM Animal             UNION
SELECT 'Employee',            Count(*) FROM Employee           UNION
SELECT 'Customer',            Count(*) FROM Customer           UNION
SELECT 'Supplier',            Count(*) FROM Supplier           UNION
SELECT 'Merchandise',         Count(*) FROM Merchandise        UNION
SELECT 'MerchandiseOrder',    Count(*) FROM MerchandiseOrder   UNION
SELECT 'OrderItem',           Count(*) FROM OrderItem          UNION
SELECT 'Sale',                Count(*) FROM Sale               UNION
SELECT 'SaleItem',            Count(*) FROM SaleItem  
ORDER BY 1;
SET NOCOUNT OFF
GO
